@@ -1,4 +1,4 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import multiprocessing
 import os
@@ -17,7 +17,6 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.50.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,7 +26,8 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.10-r1",
+apk_tools_min_version = {"edge": "2.14.0_rc1-r0",
+                         "v3.17": "2.12.10-r1",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
@@ -215,9 +215,11 @@ chroot_host_path = os.environ["PATH"] + ":/usr/sbin/"
 chroot_mount_bind = {
     "/proc": "/proc",
     "$WORK/cache_apk_$ARCH": "/var/cache/apk",
+    "$WORK/cache_appstream/$ARCH/$CHANNEL": "/mnt/appstream-data",
     "$WORK/cache_ccache_$ARCH": "/mnt/pmbootstrap-ccache",
     "$WORK/cache_distfiles": "/var/cache/distfiles",
     "$WORK/cache_git": "/mnt/pmbootstrap-git",
+    "$WORK/cache_go": "/mnt/pmbootstrap-go",
     "$WORK/cache_rust": "/mnt/pmbootstrap-rust",
     "$WORK/config_abuild": "/mnt/pmbootstrap-abuild-config",
     "$WORK/config_apk_keys": "/etc/apk/keys",
@@ -233,10 +235,16 @@ chroot_mount_bind = {
 # a no-go, but at least until this is resolved properly, let's cache the
 # dependencies and downloads as suggested in "Caching the Cargo home in CI":
 # https://doc.rust-lang.org/cargo/guide/cargo-home.html
+# Go: cache the directories "go env GOMODCACHE" and "go env GOCACHE" point to,
+# to avoid downloading dependencies over and over (GOMODCACHE, similar to the
+# rust depends caching described above) and to cache build artifacts (GOCACHE,
+# similar to ccache).
 chroot_home_symlinks = {
     "/mnt/pmbootstrap-abuild-config": "/home/pmos/.abuild",
     "/mnt/pmbootstrap-ccache": "/home/pmos/.ccache",
     "/mnt/pmbootstrap-packages": "/home/pmos/packages/pmos",
+    "/mnt/pmbootstrap-go/gocache": "/home/pmos/.cache/go-build",
+    "/mnt/pmbootstrap-go/gomodcache": "/home/pmos/go/pkg/mod",
     "/mnt/pmbootstrap-rust/registry/index": "/home/pmos/.cargo/registry/index",
     "/mnt/pmbootstrap-rust/registry/cache": "/home/pmos/.cargo/registry/cache",
     "/mnt/pmbootstrap-rust/git/db": "/home/pmos/.cargo/git/db",
@@ -289,7 +297,7 @@ build_packages = ["abuild", "build-base", "ccache", "git"]
 #     this e.g. if the order of the elements is important.
 
 # Necessary kernel config options
-necessary_kconfig_options = {
+kconfig_options = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "ANDROID_PARANOID_NETWORK": False,
@@ -310,6 +318,16 @@ necessary_kconfig_options = {
             "VT": True,
         }
     },
+    ">=2.6.0": {
+        "all": {
+            "BINFMT_ELF": True,
+        },
+    },
+    ">=3.10.0": {
+        "all": {
+            "BINFMT_SCRIPT": True,
+        },
+    },
     ">=4.0.0": {
         "all": {
             "UEVENT_HELPER": True,
@@ -335,26 +353,31 @@ necessary_kconfig_options = {
 }
 
 # Necessary waydroid kernel config options (android app support)
-necessary_kconfig_options_waydroid = {
+kconfig_options_waydroid = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
-            "SQUASHFS": True,
-            "SQUASHFS_XZ": True,
-            "SQUASHFS_XATTR": True,
-            "TMPFS_XATTR": True,
-            "ANDROID_BINDER_IPC": True,
             "ANDROID_BINDERFS": False,
             "ANDROID_BINDER_DEVICES": ["binder", "hwbinder", "vndbinder"],
+            "ANDROID_BINDER_IPC": True,
+            "ANDROID_BINDER_IPC_SELFTEST": False,
+            "BLK_DEV_LOOP": True,
+            "BPF_SYSCALL": True,
+            "BRIDGE": True,
+            "BRIDGE_VLAN_FILTERING": True,
+            "CGROUP_BPF": True,
+            "FUSE_FS": True,
+            "IP_NF_MANGLE": True,
             "NETFILTER_XTABLES": True,
             "NETFILTER_XT_MATCH_COMMENT": True,
-            "IP_NF_MANGLE": True,
-            "FUSE_FS": True,
-            "BLK_DEV_LOOP": True,
+            "PSI": True,
+            "PSI_DEFAULT_DISABLED": False,
+            "SQUASHFS": True,
+            "SQUASHFS_XATTR": True,
+            "SQUASHFS_XZ": True,
+            "TMPFS_XATTR": True,
             "TUN": True,
             "VETH": True,
             "VLAN_8021Q": True,  # prerequisite for bridge
-            "BRIDGE": True,
-            "BRIDGE_VLAN_FILTERING": True,
         }
     },
     ">=3.5": {
@@ -377,7 +400,7 @@ necessary_kconfig_options_waydroid = {
 
 # Necessary iwd kernel config options (inet wireless daemon)
 # Obtained from 'grep ADD_MISSING src/main.c' in iwd.git
-necessary_kconfig_options_iwd = {
+kconfig_options_iwd = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "ASYMMETRIC_KEY_TYPE": True,
@@ -404,7 +427,7 @@ necessary_kconfig_options_iwd = {
 }
 
 # Necessary nftables kernel config options (firewall)
-necessary_kconfig_options_nftables = {
+kconfig_options_nftables = {
     ">=3.13.0": {  # nftables support introduced here
         "all": {  # all arches
             "NETFILTER": True,
@@ -439,7 +462,7 @@ necessary_kconfig_options_nftables = {
 }
 
 # Necessary kernel config options for containers (lxc, Docker)
-necessary_kconfig_options_containers = {
+kconfig_options_containers = {
     ">=0.0.0": {  # all versions, more specifically - since >=2.5~2.6
         "all": {  # all arches
             "NAMESPACES": True,
@@ -508,7 +531,7 @@ necessary_kconfig_options_containers = {
             "CGROUP_HUGETLB": True,  # Optional section
         }
     },
-    ">=3.6 <6.1": {  # option has been dropped
+    ">=3.6 <6.1_rc1": {  # option has been dropped
         "all": {
             "MEMCG_SWAP": True,
         }
@@ -555,7 +578,7 @@ necessary_kconfig_options_containers = {
 }
 
 # Necessary zram kernel config options (RAM disk with on-the-fly compression)
-necessary_kconfig_options_zram = {
+kconfig_options_zram = {
     ">=3.14.0": {  # zram support introduced here
         "all": {  # all arches
             "ZRAM": True,
@@ -568,7 +591,7 @@ necessary_kconfig_options_zram = {
 }
 
 # Necessary netboot kernel config options
-necessary_kconfig_options_netboot = {
+kconfig_options_netboot = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "BLK_DEV_NBD": True,
@@ -578,7 +601,7 @@ necessary_kconfig_options_netboot = {
 
 # Necessary wireguard & wg-quick kernel config options
 # From https://gitweb.gentoo.org/repo/gentoo.git/tree/net-vpn/wireguard-tools/wireguard-tools-1.0.20210914.ebuild?id=76aaa1eeb6f001baaa68e6946f917ebb091bbd9d # noqa
-necessary_kconfig_options_wireguard = {
+kconfig_options_wireguard = {
     ">=5.6_rc1": {  # all versions
         "all": {  # all arches
             "WIREGUARD": True,
@@ -598,7 +621,7 @@ necessary_kconfig_options_wireguard = {
 }
 
 # Necessary file system config options
-necessary_kconfig_options_filesystems = {
+kconfig_options_filesystems = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "BTRFS_FS": True,
@@ -610,7 +633,7 @@ necessary_kconfig_options_filesystems = {
 }
 
 # Various other kernel config options
-necessary_kconfig_options_community = {
+kconfig_options_community = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "INPUT_UINPUT": True,  # buffyboard
@@ -622,7 +645,7 @@ necessary_kconfig_options_community = {
 }
 
 # Necessary UEFI boot config options
-necessary_kconfig_options_uefi = {
+kconfig_options_uefi = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "EFI_STUB": True,
@@ -694,6 +717,9 @@ apkbuild_attributes = {
     "_outdir": {},
     "_config": {},
 
+    # linux-edge
+    "_depends_dev": {"array": True},
+
     # mesa
     "_llvmver": {},
 
