@@ -1,4 +1,4 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
@@ -164,8 +164,8 @@ def create_home_from_skel(args):
 def configure_apk(args):
     """
     Copy over all official keys, and the keys used to compile local packages
-    (unless --no-local-pkgs is set). Then disable the /mnt/pmbootstrap-packages
-    repository.
+    (unless --no-local-pkgs is set). Then copy the corresponding APKINDEX files
+    and remove the /mnt/pmbootstrap-packages repository.
     """
     # Official keys
     pattern = f"{pmb.config.apk_keys_path}/*.pub"
@@ -179,6 +179,13 @@ def configure_apk(args):
     for key in glob.glob(pattern):
         pmb.helpers.run.root(args, ["cp", key, rootfs + "/etc/apk/keys/"])
 
+    # Copy over the corresponding APKINDEX files from cache
+    index_files = pmb.helpers.repo.apkindex_files(args,
+                                                  arch=args.deviceinfo["arch"],
+                                                  user_repository=False)
+    for f in index_files:
+        pmb.helpers.run.root(args, ["cp", f, rootfs + "/var/cache/apk/"])
+
     # Disable pmbootstrap repository
     pmb.helpers.run.root(args, ["sed", "-i", r"/\/mnt\/pmbootstrap-packages/d",
                                 rootfs + "/etc/apk/repositories"])
@@ -370,6 +377,25 @@ def setup_hostname(args):
     pmb.chroot.root(args, ["sed", "-i", "-e", regex, "/etc/hosts"], suffix)
 
 
+def setup_appstream(args):
+    """
+    If alpine-appstream-downloader has been downloaded, execute it to have
+    update AppStream data on new installs
+    """
+    suffix = "rootfs_" + args.device
+    installed_pkgs = pmb.chroot.apk.installed(args, suffix)
+
+    if "alpine-appstream-downloader" not in installed_pkgs or args.offline:
+        return
+
+    pmb.chroot.root(args, ["alpine-appstream-downloader",
+                           "/mnt/appstream-data"], suffix)
+    pmb.chroot.root(args, ["mkdir", "-p", "/var/lib/swcatalog"], suffix)
+    pmb.chroot.root(args, ["cp", "-r", "/mnt/appstream-data/icons",
+                           "/mnt/appstream-data/xml",
+                           "-t", "/var/lib/swcatalog"], suffix)
+
+
 def disable_sshd(args):
     if not args.no_sshd:
         return
@@ -867,7 +893,7 @@ def install_on_device_installer(args, step, steps):
            "ONDEV_CHANNEL_DESCRIPTION": channel_cfg["description"],
            "ONDEV_CHANNEL_MIRRORDIR_ALPINE": channel_cfg["mirrordir_alpine"],
            "ONDEV_CIPHER": args.cipher,
-           "ONDEV_PMBOOTSTRAP_VERSION": pmb.config.version,
+           "ONDEV_PMBOOTSTRAP_VERSION": pmb.__version__,
            "ONDEV_UI": args.ui}
     pmb.chroot.root(args, ["ondev-prepare"], suffix_installer, env=env)
 
@@ -995,7 +1021,14 @@ def create_device_rootfs(args, step, steps):
     setup_keymap(args)
 
     # Set timezone
-    pmb.chroot.root(args, ["setup-timezone", "-z", args.timezone], suffix)
+    arch = args.deviceinfo["arch"]
+    package = pmb.helpers.package.get(args, "alpine-conf", arch)
+    version = package["version"].split("-r")[0]
+
+    if not pmb.parse.version.check_string(version, ">=3.14.0"):
+        pmb.chroot.root(args, ["setup-timezone", "-z", args.timezone], suffix)
+    else:
+        pmb.chroot.root(args, ["setup-timezone", args.timezone], suffix)
 
     # Set locale
     if locale_is_set:
@@ -1006,6 +1039,8 @@ def create_device_rootfs(args, step, steps):
     # Set the hostname as the device name
     setup_hostname(args)
 
+    setup_appstream(args)
+
     disable_sshd(args)
     disable_firewall(args)
 
